#include <bastard.h>
#include <bdb.h>
#include <extension.h>


/* OUTPUT HTML : create HTML-formatted .lst file */
int plugin_main(FILE *f) {
	sys_msg( "HTML output not supported\n");
	return (0);
}
